test: skip tmem_load, only store+dealloc

This commit is contained in:
2026-05-28 09:50:48 +00:00
parent 2513e1a692
commit 61f19ce891

View File

@@ -49,16 +49,16 @@ __global__ void test_tmem_loop(float* out) {
asm volatile("tcgen05.wait::st.sync.aligned;" ::: "memory");
__syncthreads();
// Read back
if (threadIdx.x < 32) {
for (int c = 0; c < 4; c++) {
uint32_t u0, u1, u2, u3;
tmem_load(tb + c, u0, u1, u2, u3);
float v0; memcpy(&v0, &u0, 4);
if (lane == 0) out[c] = v0;
}
}
__syncthreads();
// Read back — skip for now
// if (threadIdx.x < 32) {
// for (int c = 0; c < 4; c++) {
// uint32_t u0, u1, u2, u3;
// tmem_load(tb + c, u0, u1, u2, u3);
// float v0; memcpy(&v0, &u0, 4);
// if (lane == 0) out[c] = v0;
// }
// }
// __syncthreads();
if (threadIdx.x < 32) tmem_dealloc(tb, 32);
}